Enum style::values::specified::position::AutoFlow
[−]
[src]
pub enum AutoFlow {
Row,
Column,
}Auto-placement algorithm Option
Variants
RowThe auto-placement algorithm places items by filling each row in turn, adding new rows as necessary.
ColumnThe auto-placement algorithm places items by filling each column in turn, adding new columns as necessary.